.. image:: https://img.shields.io/travis/dokipen/tubing.svg
    :target: https://travis-ci.org/dokipen/tubing/
.. image:: https://img.shields.io/coveralls/dokipen/tubing.svg
    :target: https://coveralls.io/github/dokipen/tubing?branch=master
.. image:: https://img.shields.io/pypi/v/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/
.. image:: https://img.shields.io/pypi/pyversions/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/
.. image:: https://img.shields.io/pypi/dd/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/
.. image:: https://img.shields.io/pypi/l/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/
.. image:: https://img.shields.io/pypi/wheel/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/

Tubing
======

Tubing is a Python I/O library.
